
# q-expansion of newform 1248.2.d.c, downloaded from the LMFDB on 01 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1248
weight = 2
poly_data = [256, 0, 0, -128, 80, -32, 32, -32, 28, -16, 8, -4, 5, -4, 0, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[512, -448, 1344, -208, 240, -376, 512, -104, 96, -82, 58, -29, 12, -10, 30, -5], 1088], [[-8960, 10560, -7744, 7312, -7872, 7056, -4608, 3044, -2360, 1656, -1168, 567, -244, 192, -100, 11], 2176], [[2752, -2272, 288, -1560, 2004, -1188, 780, -474, 584, -394, 197, -73, 56, -58, 21, 5], 816], [[-1792, 10816, -6336, 48, -6144, 5328, -3696, 1860, -1832, 1324, -968, 535, -212, 52, -156, 43], 6528], [[-9216, 5888, -1072, 2656, -3232, 2008, -172, 376, -436, 320, -109, -73, 56, 44, -13, -29], 3264], [[-1920, 864, -416, 1256, -1376, 1308, -764, 526, -462, 350, -175, 96, -62, 46, -19, 6], 544], [[10240, -3520, -2496, -2256, 3168, -720, -96, 300, -256, -280, -64, 185, -100, -64, -12, 53], 3264], [[3840, 3712, -4880, -64, 304, 1736, -1532, 716, -368, 286, -347, 352, -80, 10, -47, 56], 3264], [[5888, 7360, -22080, 12432, -4992, 7440, -7440, 6012, -2432, 1420, -1424, 1069, -644, 4, -12, 121], 6528], [[29056, -66496, 42816, -33360, 36672, -37488, 27696, -17292, 11840, -10204, 6632, -3469, 1412, -916, 708, -169], 6528], [[30720, -14912, -3680, -2416, 4336, -664, -1784, 2192, -1040, 622, -668, 997, -572, 46, -104, 125], 3264], [[-384, 192, -64, 144, -80, 16, 16, -20, 12, -12, 16, -15, 8, -4, 4, -3], 64], [[2304, -704, -128, -496, 640, -208, -32, 20, 40, -32, -20, 55, -20, -8, -8, 11], 192], [[-16000, 53440, -55872, 36624, -38304, 37488, -30960, 21372, -13064, 10204, -7448, 4489, -1820, 916, -708, 373], 6528], [[43776, -25792, 5840, -17648, 20384, -11408, 5084, -3860, 3584, -2404, 845, 113, -28, -328, -19, 193], 3264]]

hecke_ring_character_values = [[703, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1093, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [833, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [769, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, -1, 0, 1], [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 1, 0, 0, -1, 0, 1, 0, 0, 0, 0, 0, 0], [0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1], [0, 1, 0, 0, 0, 1, -1, 0, -1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, -1, 0, 0, 0, 0, 1, -1, 0, 0, 0, 1, 0], [0, -1, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [2, 0, 0, 1, 1, 0, 0, 0, 0, 1, 0, 0, -2, 0, 0, 0], [0, 0, 0, -1, 0, 0, 0, -2, 0, 1, 0, 0, 0, 0, 0, 0], [0, -1, 2, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 1, 0, 0, -1, 0, 0, 0, 0, 3, 0, 0], [0, 0, 0, 0, -2, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -4, 0, 0, 3, 0, 0, -1, 0, -1, 0, -1], [2, 0, 0, -1, -1, 0, 0, 0, 0, -1, -1, 0, 0, 0, -1, 0], [0, 0, -3, 0, 0, -1, 0, 0, 0, 0, 0, 1, 0, 0, 0, -1], [0, 1, 0, 0, 0, 0, -1, 0, 1, 0, 0, 1, 0, -1, 0, 1], [-4, 0, 0, -1, -1, 0, 0, 0, 0, -1, 1, 0, 2, 0, 1, 0], [0, 0, -4, 0, 0, 4, 0, 0, 4, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, -1, -1, 0, 1, 0, 0, 0, 0, 1, 0, 0], [0, 0, 0, 0, 3, 0, 0, -2, 0, 0, -1, 0, 0, 0, 1, 0], [-4, 0, 0, -1, -1, 0, 0, 0, 0, -1, 1, 0, -2, 0, 1, 0], [0, 0, 0, 3, -1, 0, 0, 1, 0, -3, -1, 0, 0, 0, 1, 0], [0, 0, 6, 0, 0, -2, 0, 0, -3, 0, 0, -1, 0, 0, 0, 1], [0, 1, 0, 0, 0, -1, -1, 0, 2, 0, 0, 1, 0, 0, 0, 1], [6, 0, 0, -1, -1, 0, 0, 0, 0, -1, 0, 0, -2, 0, 0, 0], [0, 0, 0, 5, -1, 0, 0, 1, 0, -5, -1, 0, 0, 0, 1, 0], [0, 1, 2, 0, 0, 1, 1, 0, 0, 0, 0, -1, 0, 0, 0, 1], [0, -1, 0, 0, 0, 6, 1, 0, -4, 0, 0, 2, 0, 0, 0, 2], [0, 0, 0, 3, 0, 0, 0, -2, 0, -3, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 3, 0, 0, 4, 0, 0, 1, 0, 0, 0, -1], [0, 0, 0, -2, -1, 0, 0, -2, 0, 2, 1, 0, 0, 0, -1, 0], [0, 1, -3, 0, 0, 1, 1, 0, 0, 0, 0, -1, 0, 0, 0, 1], [-2, 0, 0, 3, 3, 0, 0, 0, 0, 3, -3, 0, -4, 0, -3, 0], [0, -1, 1, 0, 0, -2, -1, 0, -2, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 0, 0, 2, 2, 0, 1, 0, 0, 3, 0, -3, 0, 3], [0, 0, 0, 1, 1, 0, 0, -3, 0, -1, 1, 0, 0, 0, -1, 0], [0, 0, 0, 0, 0, -3, 0, 0, 0, 0, 0, -3, 0, 0, 0, -3], [-8, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, 2, 0, 2, 0], [0, -1, 0, 0, 0, -3, 1, 0, 3, 0, 0, 0, 0, 2, 0, 0], [2, 0, 0, -2, -2, 0, 0, 0, 0, -2, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, -4, 0, 0, -2, 0, 1, 1, 0, 0, 0, -1, 0], [0, 2, 2, 0, 0, -2, 2, 0, -4, 0, 0, -2, 0, 0, 0, 2], [0, -3, 0, 0, 0, -2, -3, 0, 1, 0, 0, 3, 0, 0, 0, -3], [0, 3, 5, 0, 0, -1, 3, 0, -2, 0, 0, -1, 0, 0, 0, 1], [0, -2, 0, 0, 0, 8, 2, 0, -5, 0, 0, 3, 0, 3, 0, 3], [-4, 0, 0, 4, 4, 0, 0, 0, 0, 4, -3, 0, -4, 0, -3, 0], [0, 0, 0, 1, 1, 0, 0, 2, 0, -1, 2, 0, 0, 0, -2, 0], [0, 3, 0, 0, 0, -2, -3, 0, -1, 0, 0, -3, 0, 3, 0, -3], [2, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, 2, 0, -2, 0], [0, 1, 0, 0, 0, -1, -1, 0, -3, 0, 0, -4, 0, 4, 0, -4], [0, 0, 0, -4, 4, 0, 0, 0, 0, 4, 1, 0, 0, 0, -1, 0], [0, 1, 0, 0, 0, -3, -1, 0, 4, 0, 0, 1, 0, -4, 0, 1], [0, 0, 0, 3, 7, 0, 0, -2, 0, -3, 1, 0, 0, 0, -1, 0], [0, 1, -3, 0, 0, 5, 1, 0, 4, 0, 0, -1, 0, 0, 0, 1], [-8, 0, 0, 1, 1, 0, 0, 0, 0, 1, -3, 0, -2, 0, -3, 0], [0, 0, 0, 0, 5, 0, 0, -2, 0, 0, 1, 0, 0, 0, -1, 0], [0, 1, 2, 0, 0, 1, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -1, 6, 0, 0, 0, 0, 1, -1, 0, 0, 0, 1, 0], [0, 3, -1, 0, 0, 2, 3, 0, 2, 0, 0, 0, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 2, 0, -1, 0, 0, -1, 0, -2, 0, -1], [2, 0, 0, 5, 5, 0, 0, 0, 0, 5, -4, 0, -4, 0, -4, 0], [0, 0, 0, -2, 1, 0, 0, -2, 0, 2, -1, 0, 0, 0, 1, 0], [0, -2, 1, 0, 0, 3, -2, 0, 6, 0, 0, 3, 0, 0, 0, -3], [14, 0, 0, 5, 5, 0, 0, 0, 0, 5, -4, 0, -4, 0, -4, 0], [0, 0, 0, 0, 0, 1, 0, 0, -3, 0, 0, -2, 0, 4, 0, -2], [-4, 0, 0, -2, -2, 0, 0, 0, 0, -2, 1, 0, 4, 0, 1, 0], [0, 0, 0, 0, 3, 0, 0, -6, 0, 0, 1, 0, 0, 0, -1, 0], [0, 0, 0, 0, 0, 4, 0, 0, -9, 0, 0, -5, 0, 5, 0, -5], [0, -2, 0, 0, 0, 0, -2, 0, 1, 0, 0, 1, 0, 0, 0, -1], [-2, 0, 0, -2, -2, 0, 0, 0, 0, -2, 0, 0, 8, 0, 0, 0], [0, -1, 1, 0, 0, 2, -1, 0, 2, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -3, 0, 0, 5, 0, 0, 2, 0, -3, 0, 2], [0, 0, 0, 3, 5, 0, 0, -4, 0, -3, 1, 0, 0, 0, -1, 0], [18, 0, 0, 4, 4, 0, 0, 0, 0, 4, -2, 0, -2, 0, -2, 0], [0, 0, 0, 3, -4, 0, 0, 8, 0, -3, 0, 0, 0, 0, 0, 0], [12, 0, 0, 5, 5, 0, 0, 0, 0, 5, -5, 0, -8, 0, -5, 0], [0, 2, 0, 0, 0, -1, -2, 0, 2, 0, 0, 1, 0, -10, 0, 1], [-4, 0, 0, -6, -6, 0, 0, 0, 0, -6, 3, 0, 4, 0, 3, 0], [0, 1, 0, 0, 0, -4, -1, 0, 7, 0, 0, 3, 0, -7, 0, 3], [4, 0, 0, 3, 3, 0, 0, 0, 0, 3, -2, 0, -6, 0, -2, 0], [0, -1, -6, 0, 0, 1, -1, 0, 3, 0, 0, 2, 0, 0, 0, -2], [0, -3, 0, 0, 0, 4, 3, 0, -8, 0, 0, -4, 0, 8, 0, -4], [0, 0, 0, 3, 0, 0, 0, 8, 0, -3, -2, 0, 0, 0, 2, 0], [-18, 0, 0, -2, -2, 0, 0, 0, 0, -2, 4, 0, 6, 0, 4, 0], [0, 0, 0, -3, 8, 0, 0, -4, 0, 3, -3, 0, 0, 0, 3, 0], [0, -1, 3, 0, 0, 0, -1, 0, -4, 0, 0, -4, 0, 0, 0, 4], [0, -3, 0, 0, 0, -1, 3, 0, 1, 0, 0, 0, 0, -4, 0, 0], [0, 2, 0, 0, 0, -7, -2, 0, 5, 0, 0, -2, 0, 1, 0, -2], [0, -1, -7, 0, 0, 2, -1, 0, 2, 0, 0, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, -6, -1, 0, 9, 0, 0, 3, 0, -8, 0, 3], [0, -1, 11, 0, 0, -8, -1, 0, -8, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 10, 0, 0, -10, 0, 0, 0, 0, 6, 0, 0], [0, 0, 0, 2, 1, 0, 0, 4, 0, -2, -1, 0, 0, 0, 1, 0], [0, 0, 0, -2, 2, 0, 0, 7, 0, 2, 1, 0, 0, 0, -1, 0], [0, -3, -4, 0, 0, -1, -3, 0, 0, 0, 0, 1, 0, 0, 0, -1], [6, 0, 0, 3, 3, 0, 0, 0, 0, 3, -2, 0, -8, 0, -2, 0], [0, 0, 4, 0, 0, -3, 0, 0, -6, 0, 0, -3, 0, 0, 0, 3], [0, 0, 0, -1, -4, 0, 0, 6, 0, 1, 1, 0, 0, 0, -1, 0], [0, 0, 0, 0, 0, -1, 0, 0, 0, 0, 0, -1, 0, 0, 0, -1], [0, 0, 0, 0, -12, 0, 0, 4, 0, 0, 1, 0, 0, 0, -1, 0], [0, -2, -6, 0, 0, 7, -2, 0, 13, 0, 0, 6, 0, 0, 0, -6], [16, 0, 0, -1, -1, 0, 0, 0, 0, -1, 1, 0, -2, 0, 1, 0], [0, 2, 0, 0, 0, 4, -2, 0, -3, 0, 0, 1, 0, 7, 0, 1], [0, 0, 0, 7, -6, 0, 0, 0, 0, -7, 0, 0, 0, 0, 0, 0], [0, 3, 0, 0, 0, 1, -3, 0, -8, 0, 0, -7, 0, 4, 0, -7], [12, 0, 0, -4, -4, 0, 0, 0, 0, -4, 5, 0, -2, 0, 5, 0], [0, 3, -8, 0, 0, 7, 3, 0, 5, 0, 0, -2, 0, 0, 0, 2], [-14, 0, 0, -4, -4, 0, 0, 0, 0, -4, -2, 0, -2, 0, -2, 0], [0, 0, 0, -6, -5, 0, 0, 6, 0, 6, -3, 0, 0, 0, 3, 0], [0, 3, 9, 0, 0, 6, 3, 0, 4, 0, 0, -2, 0, 0, 0, 2], [0, -3, 3, 0, 0, -9, -3, 0, -6, 0, 0, 3, 0, 0, 0, -3], [0, 0, 0, -1, -1, 0, 0, 1, 0, 1, -1, 0, 0, 0, 1, 0], [0, 0, -9, 0, 0, -7, 0, 0, 0, 0, 0, 7, 0, 0, 0, -7], [0, -3, 0, 0, 0, 11, 3, 0, -14, 0, 0, -3, 0, 2, 0, -3], [0, 0, 0, -2, -10, 0, 0, 8, 0, 2, -2, 0, 0, 0, 2, 0], [0, -1, 0, 0, 0, -11, 1, 0, 11, 0, 0, 0, 0, 2, 0, 0], [-6, 0, 0, -2, -2, 0, 0, 0, 0, -2, 2, 0, -8, 0, 2, 0], [18, 0, 0, 2, 2, 0, 0, 0, 0, 2, -1, 0, -8, 0, -1, 0], [0, 0, 0, 1, -1, 0, 0, -3, 0, -1, 3, 0, 0, 0, -3, 0], [0, 1, 0, 0, 0, -9, -1, 0, 13, 0, 0, 4, 0, -5, 0, 4], [0, 0, -13, 0, 0, 7, 0, 0, 8, 0, 0, 1, 0, 0, 0, -1], [0, 0, 0, -1, 5, 0, 0, 2, 0, 1, -1, 0, 0, 0, 1, 0], [-22, 0, 0, -2, -2, 0, 0, 0, 0, -2, 0, 0, 2, 0, 0, 0], [0, -2, 0, 0, 0, 8, 2, 0, -3, 0, 0, 5, 0, -2, 0, 5], [0, 5, 2, 0, 0, 3, 5, 0, 2, 0, 0, -1, 0, 0, 0, 1], [8, 0, 0, -2, -2, 0, 0, 0, 0, -2, 3, 0, 6, 0, 3, 0], [0, 1, 7, 0, 0, -6, 1, 0, -6, 0, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, -11, 4, 0, 13, 0, 0, 2, 0, -5, 0, 2], [0, 1, 6, 0, 0, -3, 1, 0, -5, 0, 0, -2, 0, 0, 0, 2], [10, 0, 0, 7, 7, 0, 0, 0, 0, 7, -5, 0, -12, 0, -5, 0], [0, 0, 0, -7, -4, 0, 0, -6, 0, 7, 2, 0, 0, 0, -2, 0], [14, 0, 0, -4, -4, 0, 0, 0, 0, -4, -2, 0, 0, 0, -2, 0], [0, 0, 0, 6, 11, 0, 0, 0, 0, -6, -2, 0, 0, 0, 2, 0], [0, -1, -1, 0, 0, 8, -1, 0, 12, 0, 0, 4, 0, 0, 0, -4], [0, 0, 0, 4, -14, 0, 0, 2, 0, -4, 4, 0, 0, 0, -4, 0], [0, 0, 0, -4, 4, 0, 0, 5, 0, 4, -3, 0, 0, 0, 3, 0], [0, -4, -1, 0, 0, 3, -4, 0, 4, 0, 0, 1, 0, 0, 0, -1], [0, 0, 0, 0, -11, 0, 0, 2, 0, 0, -2, 0, 0, 0, 2, 0], [0, 3, 6, 0, 0, 1, 3, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, -5, 1, 0, 3, 0, 0, -2, 0, -7, 0, -2], [-8, 0, 0, -2, -2, 0, 0, 0, 0, -2, 2, 0, 10, 0, 2, 0], [0, 4, 0, 0, 0, 4, -4, 0, -9, 0, 0, -5, 0, 7, 0, -5], [12, 0, 0, 4, 4, 0, 0, 0, 0, 4, -1, 0, 2, 0, -1, 0], [0, 0, 0, 6, 0, 0, 0, 4, 0, -6, 0, 0, 0, 0, 0, 0], [0, 1, 20, 0, 0, -13, 1, 0, -17, 0, 0, -4, 0, 0, 0, 4], [0, -1, 0, 0, 0, 4, 1, 0, -7, 0, 0, -3, 0, 7, 0, -3], [-4, 0, 0, -4, -4, 0, 0, 0, 0, -4, -3, 0, 2, 0, -3, 0], [0, 0, 0, 6, -10, 0, 0, 14, 0, -6, -1, 0, 0, 0, 1, 0], [0, -3, 6, 0, 0, 4, -3, 0, -1, 0, 0, -5, 0, 0, 0, 5], [0, 1, 0, 0, 0, 5, -1, 0, 1, 0, 0, 6, 0, -14, 0, 6], [0, 1, 2, 0, 0, 0, 1, 0, -9, 0, 0, -9, 0, 0, 0, 9], [0, 1, 0, 0, 0, -17, -1, 0, 11, 0, 0, -6, 0, 2, 0, -6], [0, 2, 0, 0, 0, -6, 2, 0, -6, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, -7, 0, 0, 6, 0, 0, -1, 0, 0, 0, 1, 0], [-12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 6, 0, 0, 0], [0, 0, 0, 4, -13, 0, 0, 8, 0, -4, -2, 0, 0, 0, 2, 0], [0, 0, 0, 0, 0, -8, 0, 0, 7, 0, 0, -1, 0, 1, 0, -1], [0, 0, 0, 2, 2, 0, 0, 0, 0, -2, 1, 0, 0, 0, -1, 0], [0, -4, 9, 0, 0, -12, -4, 0, -10, 0, 0, 2, 0, 0, 0, -2], [0, -1, 0, 0, 0, -8, 1, 0, 9, 0, 0, 1, 0, -2, 0, 1], [0, 0, 0, 4, 17, 0, 0, -4, 0, -4, 1, 0, 0, 0, -1, 0], [0, -3, 0, 0, 0, -4, 3, 0, 3, 0, 0, -1, 0, 11, 0, -1], [0, -4, 8, 0, 0, -6, -4, 0, 1, 0, 0, 7, 0, 0, 0, -7], [-20, 0, 0, 5, 5, 0, 0, 0, 0, 5, -1, 0, -2, 0, -1, 0], [-4, 0, 0, 1, 1, 0, 0, 0, 0, 1, 1, 0, 12, 0, 1, 0], [0, 0, 0, 5, 5, 0, 0, 5, 0, -5, 3, 0, 0, 0, -3, 0], [0, -3, 0, 0, 0, 1, 3, 0, 3, 0, 0, 4, 0, 7, 0, 4], [22, 0, 0, 5, 5, 0, 0, 0, 0, 5, 2, 0, -4, 0, 2, 0], [0, -5, 0, 0, 0, 7, 5, 0, -7, 0, 0, 0, 0, 0, 0, 0], [-2, 0, 0, 2, 2, 0, 0, 0, 0, 2, -4, 0, -4, 0, -4, 0], [0, 0, -10, 0, 0, 8, 0, 0, 3, 0, 0, -5, 0, 0, 0, 5], [0, 0, 0, -7, -5, 0, 0, 0, 0, 7, 4, 0, 0, 0, -4, 0], [0, -4, 3, 0, 0, -9, -4, 0, -4, 0, 0, 5, 0, 0, 0, -5], [0, 0, 0, 0, 3, 0, 0, 8, 0, 0, 1, 0, 0, 0, -1, 0], [0, 0, -2, 0, 0, 2, 0, 0, 9, 0, 0, 7, 0, 0, 0, -7], [16, 0, 0, 3, 3, 0, 0, 0, 0, 3, -5, 0, -14, 0, -5, 0], [0, 5, -1, 0, 0, -2, 5, 0, -4, 0, 0, -2, 0, 0, 0, 2], [0, 1, 0, 0, 0, 15, -1, 0, -8, 0, 0, 7, 0, -6, 0, 7], [-14, 0, 0, 1, 1, 0, 0, 0, 0, 1, -1, 0, -4, 0, -1, 0], [0, 0, 0, 1, 6, 0, 0, -10, 0, -1, 4, 0, 0, 0, -4, 0], [0, 2, 0, 0, 0, -2, -2, 0, 1, 0, 0, -1, 0, -5, 0, -1], [0, 0, 0, -3, 7, 0, 0, -12, 0, 3, 3, 0, 0, 0, -3, 0], [14, 0, 0, 1, 1, 0, 0, 0, 0, 1, -1, 0, 0, 0, -1, 0], [0, 3, -3, 0, 0, -4, 3, 0, -12, 0, 0, -8, 0, 0, 0, 8], [-10, 0, 0, 4, 4, 0, 0, 0, 0, 4, 2, 0, 0, 0, 2, 0], [0, -4, 0, 0, 0, 12, 4, 0, -7, 0, 0, 5, 0, 5, 0, 5], [28, 0, 0, 7, 7, 0, 0, 0, 0, 7, -4, 0, -2, 0, -4, 0], [0, 3, 0, 0, 0, -3, -3, 0, 1, 0, 0, -2, 0, 5, 0, -2], [0, 0, 0, 0, 0, 11, 0, 0, 4, 0, 0, -7, 0, 0, 0, 7], [0, 0, 0, -6, -13, 0, 0, 2, 0, 6, 1, 0, 0, 0, -1, 0], [0, -7, 0, 0, 0, 2, 7, 0, 2, 0, 0, 4, 0, -6, 0, 4], [0, 0, 0, 4, -14, 0, 0, 8, 0, -4, 2, 0, 0, 0, -2, 0], [24, 0, 0, -1, -1, 0, 0, 0, 0, -1, 9, 0, 0, 0, 9, 0], [6, 0, 0, 8, 8, 0, 0, 0, 0, 8, -6, 0, -16, 0, -6, 0], [0, 0, 0, 6, 5, 0, 0, -6, 0, -6, 3, 0, 0, 0, -3, 0], [0, -3, 0, 0, 0, -1, 3, 0, -5, 0, 0, -6, 0, 2, 0, -6], [0, 0, 0, 0, -5, 0, 0, -4, 0, 0, 2, 0, 0, 0, -2, 0], [0, -4, 0, 0, 0, 4, -4, 0, 7, 0, 0, 3, 0, 0, 0, -3], [-6, 0, 0, 9, 9, 0, 0, 0, 0, 9, -10, 0, -10, 0, -10, 0], [-24, 0, 0, -1, -1, 0, 0, 0, 0, -1, -6, 0, 2, 0, -6, 0], [0, -1, 0, 0, 0, 9, 1, 0, -7, 0, 0, 2, 0, -7, 0, 2], [0, 0, 0, -10, 0, 0, 0, 9, 0, 10, 0, 0, 0, 0, 0, 0], [0, -1, -7, 0, 0, -1, -1, 0, 8, 0, 0, 9, 0, 0, 0, -9], [0, 1, 0, 0, 0, 7, -1, 0, -2, 0, 0, 5, 0, 4, 0, 5], [0, 0, 0, 1, 6, 0, 0, -16, 0, -1, 0, 0, 0, 0, 0, 0], [0, 2, 10, 0, 0, -7, 2, 0, -11, 0, 0, -4, 0, 0, 0, 4], [-12, 0, 0, 2, 2, 0, 0, 0, 0, 2, -6, 0, -2, 0, -6, 0], [0, 0, 0, 0, 6, 0, 0, 3, 0, 0, -2, 0, 0, 0, 2, 0], [0, 0, -8, 0, 0, 8, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0], [0, -4, 0, 0, 0, 0, 4, 0, -3, 0, 0, -3, 0, 7, 0, -3], [0, 5, 0, 0, 0, -14, -5, 0, 11, 0, 0, -3, 0, -7, 0, -3], [-42, 0, 0, -8, -8, 0, 0, 0, 0, -8, 4, 0, 2, 0, 4, 0], [0, 7, 8, 0, 0, 1, 7, 0, 2, 0, 0, 1, 0, 0, 0, -1], [0, 0, 0, 5, -1, 0, 0, -10, 0, -5, 0, 0, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, -4, 0, -5, 0, 0, -5, 0, 7, 0, -5], [0, 0, 0, -1, -14, 0, 0, 10, 0, 1, -1, 0, 0, 0, 1, 0], [-6, 0, 0, 0, 0, 0, 0, 0, 0, 0, -2, 0, -8, 0, -2, 0], [0, -1, 7, 0, 0, 1, -1, 0, 2, 0, 0, 1, 0, 0, 0, -1], [0, 0, 0, -6, 13, 0, 0, -2, 0, 6, -1, 0, 0, 0, 1, 0], [0, -1, 15, 0, 0, -11, -1, 0, -10, 0, 0, 1, 0, 0, 0, -1], [0, -1, 0, 0, 0, -12, 1, 0, 7, 0, 0, -5, 0, -4, 0, -5], [-4, 0, 0, -7, -7, 0, 0, 0, 0, -7, 3, 0, 10, 0, 3, 0], [0, 0, 0, -3, 3, 0, 0, -8, 0, 3, -2, 0, 0, 0, 2, 0], [0, 1, 0, 0, 0, 9, -1, 0, -4, 0, 0, 5, 0, 8, 0, 5], [0, -1, -6, 0, 0, 5, -1, 0, 14, 0, 0, 9, 0, 0, 0, -9], [0, 3, 0, 0, 0, -5, -3, 0, -3, 0, 0, -8, 0, 15, 0, -8], [-4, 0, 0, -12, -12, 0, 0, 0, 0, -12, 8, 0, 10, 0, 8, 0], [0, 5, -8, 0, 0, 11, 5, 0, 6, 0, 0, -5, 0, 0, 0, 5], [0, -1, -1, 0, 0, -4, -1, 0, -8, 0, 0, -4, 0, 0, 0, 4], [0, 0, 0, -9, -15, 0, 0, 7, 0, 9, -2, 0, 0, 0, 2, 0], [0, -1, -12, 0, 0, 0, -1, 0, -2, 0, 0, -2, 0, 0, 0, 2], [0, -3, 0, 0, 0, -2, 3, 0, -3, 0, 0, -5, 0, 13, 0, -5], [-20, 0, 0, -7, -7, 0, 0, 0, 0, -7, 3, 0, -2, 0, 3, 0], [0, 0, 0, 4, -7, 0, 0, 2, 0, -4, 2, 0, 0, 0, -2, 0], [0, 1, 0, 0, 0, 7, -1, 0, -8, 0, 0, -1, 0, -2, 0, -1], [0, 3, 0, 0, 0, -7, -3, 0, 9, 0, 0, 2, 0, -2, 0, 2], [0, 1, 0, 0, 0, -19, -1, 0, 23, 0, 0, 4, 0, -1, 0, 4], [0, -3, -2, 0, 0, -10, -3, 0, -15, 0, 0, -5, 0, 0, 0, 5], [0, 1, -4, 0, 0, 11, 1, 0, 0, 0, 0, -11, 0, 0, 0, 11], [12, 0, 0, 10, 10, 0, 0, 0, 0, 10, -3, 0, -4, 0, -3, 0], [0, 0, 0, -12, -5, 0, 0, 4, 0, 12, -1, 0, 0, 0, 1, 0], [0, -4, 0, 0, 0, -20, 4, 0, 17, 0, 0, -3, 0, 6, 0, -3], [0, -2, 15, 0, 0, -2, -2, 0, -4, 0, 0, -2, 0, 0, 0, 2], [0, -1, 0, 0, 0, -11, 1, 0, 13, 0, 0, 2, 0, -13, 0, 2], [0, -5, -3, 0, 0, 12, -5, 0, 20, 0, 0, 8, 0, 0, 0, -8], [0, 3, 0, 0, 0, -3, -3, 0, 9, 0, 0, 6, 0, -12, 0, 6], [4, 0, 0, -4, -4, 0, 0, 0, 0, -4, -9, 0, -8, 0, -9, 0], [0, 0, 0, -7, 20, 0, 0, -12, 0, 7, -2, 0, 0, 0, 2, 0], [0, 4, 0, 0, 0, -3, -4, 0, -5, 0, 0, -8, 0, 15, 0, -8], [20, 0, 0, 10, 10, 0, 0, 0, 0, 10, -9, 0, -10, 0, -9, 0], [0, 0, 0, 2, 6, 0, 0, -18, 0, -2, 2, 0, 0, 0, -2, 0], [0, 7, 0, 0, 0, -1, -7, 0, -1, 0, 0, -2, 0, 5, 0, -2], [-10, 0, 0, -2, -2, 0, 0, 0, 0, -2, 8, 0, 8, 0, 8, 0], [0, 1, 23, 0, 0, -8, 1, 0, -14, 0, 0, -6, 0, 0, 0, 6], [0, 0, 0, 4, 2, 0, 0, 10, 0, -4, -2, 0, 0, 0, 2, 0], [8, 0, 0, 7, 7, 0, 0, 0, 0, 7, 3, 0, -8, 0, 3, 0], [0, 2, -10, 0, 0, -8, 2, 0, -2, 0, 0, 6, 0, 0, 0, -6], [0, 3, 0, 0, 0, 8, -3, 0, -11, 0, 0, -3, 0, -2, 0, -3], [-2, 0, 0, 5, 5, 0, 0, 0, 0, 5, 4, 0, 2, 0, 4, 0], [2, 0, 0, -10, -10, 0, 0, 0, 0, -10, -2, 0, 8, 0, -2, 0], [0, 0, 0, 6, 13, 0, 0, 0, 0, -6, 3, 0, 0, 0, -3, 0], [0, -1, 16, 0, 0, -4, -1, 0, -5, 0, 0, -1, 0, 0, 0, 1], [0, 0, 0, -13, 12, 0, 0, -10, 0, 13, 1, 0, 0, 0, -1, 0], [0, 0, 0, -7, -2, 0, 0, 0, 0, 7, -2, 0, 0, 0, 2, 0], [0, -2, -11, 0, 0, -1, -2, 0, 8, 0, 0, 9, 0, 0, 0, -9], [0, 0, 0, -4, 20, 0, 0, -1, 0, 4, -6, 0, 0, 0, 6, 0], [-14, 0, 0, -11, -11, 0, 0, 0, 0, -11, 9, 0, 8, 0, 9, 0], [0, -3, -1, 0, 0, 0, -3, 0, -14, 0, 0, -14, 0, 0, 0, 14], [0, 0, 0, 3, 3, 0, 0, 0, 0, 3, -5, 0, 0, 0, -5, 0], [0, 2, -2, 0, 0, -12, 2, 0, -9, 0, 0, 3, 0, 0, 0, -3], [18, 0, 0, 4, 4, 0, 0, 0, 0, 4, -4, 0, -16, 0, -4, 0], [0, -1, -3, 0, 0, -2, -1, 0, 8, 0, 0, 10, 0, 0, 0, -10], [0, -1, 0, 0, 0, -1, 1, 0, 1, 0, 0, 0, 0, -3, 0, 0], [-26, 0, 0, -12, -12, 0, 0, 0, 0, -12, 4, 0, -4, 0, 4, 0], [0, 0, 0, 7, 7, 0, 0, 0, 0, 7, 1, 0, -8, 0, 1, 0], [0, 1, 0, 0, 0, -8, -1, 0, 15, 0, 0, 7, 0, 0, 0, 7], [0, -4, 0, 0, 0, 12, 4, 0, -19, 0, 0, -7, 0, 12, 0, -7], [0, 3, -13, 0, 0, 5, 3, 0, 6, 0, 0, 1, 0, 0, 0, -1], [0, 0, 0, 0, 0, 6, 0, 0, 3, 0, 0, 9, 0, -8, 0, 9], [22, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 0, -6, 0, 2, 0], [0, 1, -7, 0, 0, 12, 1, 0, 14, 0, 0, 2, 0, 0, 0, -2], [0, 0, 0, 0, 0, 10, 0, 0, 4, 0, 0, 14, 0, -20, 0, 14], [8, 0, 0, -1, -1, 0, 0, 0, 0, -1, -2, 0, -10, 0, -2, 0], [0, 0, 0, 9, -4, 0, 0, 2, 0, -9, 1, 0, 0, 0, -1, 0], [0, 4, 5, 0, 0, 12, 4, 0, 12, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, -6, -16, 0, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0], [0, 0, 0, -3, 7, 0, 0, 3, 0, 3, 3, 0, 0, 0, -3, 0], [0, -3, 0, 0, 0, -18, 3, 0, 23, 0, 0, 5, 0, -2, 0, 5], [0, 0, 0, 6, -7, 0, 0, -2, 0, -6, -1, 0, 0, 0, 1, 0], [0, 4, 0, 0, 0, 0, -4, 0, 1, 0, 0, 1, 0, -3, 0, 1], [-20, 0, 0, -2, -2, 0, 0, 0, 0, -2, -2, 0, 6, 0, -2, 0], [0, 0, 0, 0, 2, 0, 0, -8, 0, 0, 2, 0, 0, 0, -2, 0], [0, -5, -4, 0, 0, 7, -5, 0, 13, 0, 0, 6, 0, 0, 0, -6], [0, 0, 0, 2, 8, 0, 0, -6, 0, -2, -4, 0, 0, 0, 4, 0], [0, 1, 0, 0, 0, 10, -1, 0, -5, 0, 0, 5, 0, -6, 0, 5], [0, -6, -17, 0, 0, 7, -6, 0, 6, 0, 0, -1, 0, 0, 0, 1], [-20, 0, 0, 2, 2, 0, 0, 0, 0, 2, 5, 0, 10, 0, 5, 0], [0, 0, 0, -8, -5, 0, 0, 4, 0, 8, 4, 0, 0, 0, -4, 0], [0, -6, -10, 0, 0, 10, -6, 0, 15, 0, 0, 5, 0, 0, 0, -5]]
